==> DateTime-Locale-1.36.tar.gz: DateTime-Locale-1.36/share/ewo.pl <==
{
  am_pm_abbreviated => [
    "k\N{U+00ed}k\N{U+00ed}r\N{U+00ed}g",
    "ng\N{U+0259}g\N{U+00f3}g\N{U+0259}le",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ewo",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "m\N{U+0254}\N{U+0301}n",
    "smb",
    "sml",
    "smn",
    "f\N{U+00fa}l",
    "s\N{U+00e9}r",
    "s\N{U+0254}\N{U+0301}n",
  ],
  day_format_narrow => [
    "m",
    "s",
    "s",
    "s",
    "f",
    "s",
    "s",
  ],
  day_format_wide => [
    "m\N{U+0254}\N{U+0301}ndi",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}b\N{U+025b}\N{U+030c}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}l\N{U+025b}\N{U+0301}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}nyi",
    "f\N{U+00fa}lad\N{U+00e9}",
    "s\N{U+00e9}rad\N{U+00e9}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254}",
  ],
  day_stand_alone_abbreviated => [
    "m\N{U+0254}\N{U+0301}n",
    "smb",
    "sml",
    "smn",
    "f\N{U+00fa}l",
    "s\N{U+00e9}r",
    "s\N{U+0254}\N{U+0301}n",
  ],
  day_stand_alone_narrow => [
    "m",
    "s",
    "s",
    "s",
    "f",
    "s",
    "s",
  ],
  day_stand_alone_wide => [
    "m\N{U+0254}\N{U+0301}ndi",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}b\N{U+025b}\N{U+030c}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}l\N{U+025b}\N{U+0301}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}nyi",
    "f\N{U+00fa}lad\N{U+00e9}",
    "s\N{U+00e9}rad\N{U+00e9}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254}",
  ],
  era_abbreviated => [
    "oyk",
    "ayk",
  ],
  era_narrow => [
    "oyk",
    "ayk",
  ],
  era_wide => [
    "os\N{U+00fa}s\N{U+00fa}a Y\N{U+00e9}sus kiri",
    "\N{U+00e1}mvus Y\N{U+00e9}sus Kir\N{U+00ed}s",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Ewondo",
  month_format_abbreviated => [
    "ngo",
    "ngb",
    "ngl",
    "ngn",
    "ngt",
    "ngs",
    "ngz",
    "ngm",
    "nge",
    "nga",
    "ngad",
    "ngab",
  ],
  month_format_narrow => [
    "o",
    "b",
    "l",
    "n",
    "t",
    "s",
    "z",
    "m",
    "e",
    "a",
    "d",
    "b",
  ],
  month_format_wide => [
    "ng\N{U+0254}n os\N{U+00fa}",
    "ng\N{U+0254}n b\N{U+025b}\N{U+030c}",
    "ng\N{U+0254}n l\N{U+00e1}la",
    "ng\N{U+0254}n nyina",
    "ng\N{U+0254}n t\N{U+00e1}na",
    "ng\N{U+0254}n sam\N{U+0259}na",
    "ng\N{U+0254}n zamgb\N{U+00e1}la",
    "ng\N{U+0254}n mwom",
    "ng\N{U+0254}n ebul\N{U+00fa}",
    "ng\N{U+0254}n aw\N{U+00f3}m",
    "ng\N{U+0254}n aw\N{U+00f3}m ai dzi\N{U+00e1}",
    "ng\N{U+0254}n aw\N{U+00f3}m ai b\N{U+025b}\N{U+030c}",
  ],
  month_stand_alone_abbreviated => [
    "ngo",
    "ngb",
    "ngl",
    "ngn",
    "ngt",
    "ngs",
    "ngz",
    "ngm",
    "nge",
    "nga",
    "ngad",
    "ngab",
  ],
  month_stand_alone_narrow => [
    "o",
    "b",
    "l",
    "n",
    "t",
    "s",
    "z",
    "m",
    "e",
    "a",
    "d",
    "b",
  ],
  month_stand_alone_wide => [
    "ng\N{U+0254}n os\N{U+00fa}",
    "ng\N{U+0254}n b\N{U+025b}\N{U+030c}",
    "ng\N{U+0254}n l\N{U+00e1}la",
    "ng\N{U+0254}n nyina",
    "ng\N{U+0254}n t\N{U+00e1}na",
    "ng\N{U+0254}n sam\N{U+0259}na",
    "ng\N{U+0254}n zamgb\N{U+00e1}la",
    "ng\N{U+0254}n mwom",
    "ng\N{U+0254}n ebul\N{U+00fa}",
    "ng\N{U+0254}n aw\N{U+00f3}m",
    "ng\N{U+0254}n aw\N{U+00f3}m ai dzi\N{U+00e1}",
    "ng\N{U+0254}n aw\N{U+00f3}m ai b\N{U+025b}\N{U+030c}",
  ],
  name => "Ewondo",
  native_language => "ewondo",
  native_name => "ewondo",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "nno",
    "nnb",
    "nnl",
    "nnny",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n as\N{U+00fa}",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n b\N{U+025b}\N{U+030c}",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n l\N{U+00e1}la",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n nyina",
  ],
  quarter_stand_alone_abbreviated => [
    "nno",
    "nnb",
    "nnl",
    "nnny",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n as\N{U+00fa}",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n b\N{U+025b}\N{U+030c}",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n l\N{U+00e1}la",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n nyina",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/ewo.pl <==
{
  am_pm_abbreviated => [
    "k\N{U+00ed}k\N{U+00ed}r\N{U+00ed}g",
    "ng\N{U+0259}g\N{U+00f3}g\N{U+0259}le",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ewo",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "m\N{U+0254}\N{U+0301}n",
    "smb",
    "sml",
    "smn",
    "f\N{U+00fa}l",
    "s\N{U+00e9}r",
    "s\N{U+0254}\N{U+0301}n",
  ],
  day_format_narrow => [
    "m",
    "s",
    "s",
    "s",
    "f",
    "s",
    "s",
  ],
  day_format_wide => [
    "m\N{U+0254}\N{U+0301}ndi",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}b\N{U+025b}\N{U+030c}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}l\N{U+025b}\N{U+0301}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}nyi",
    "f\N{U+00fa}lad\N{U+00e9}",
    "s\N{U+00e9}rad\N{U+00e9}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254}",
  ],
  day_stand_alone_abbreviated => [
    "m\N{U+0254}\N{U+0301}n",
    "smb",
    "sml",
    "smn",
    "f\N{U+00fa}l",
    "s\N{U+00e9}r",
    "s\N{U+0254}\N{U+0301}n",
  ],
  day_stand_alone_narrow => [
    "m",
    "s",
    "s",
    "s",
    "f",
    "s",
    "s",
  ],
  day_stand_alone_wide => [
    "m\N{U+0254}\N{U+0301}ndi",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}b\N{U+025b}\N{U+030c}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}l\N{U+025b}\N{U+0301}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254} m\N{U+0259}l\N{U+00fa} m\N{U+0259}\N{U+0301}nyi",
    "f\N{U+00fa}lad\N{U+00e9}",
    "s\N{U+00e9}rad\N{U+00e9}",
    "s\N{U+0254}\N{U+0301}nd\N{U+0254}",
  ],
  era_abbreviated => [
    "oyk",
    "ayk",
  ],
  era_narrow => [
    "oyk",
    "ayk",
  ],
  era_wide => [
    "os\N{U+00fa}s\N{U+00fa}a Y\N{U+00e9}sus kiri",
    "\N{U+00e1}mvus Y\N{U+00e9}sus Kir\N{U+00ed}s",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Ewondo",
  month_format_abbreviated => [
    "ngo",
    "ngb",
    "ngl",
    "ngn",
    "ngt",
    "ngs",
    "ngz",
    "ngm",
    "nge",
    "nga",
    "ngad",
    "ngab",
  ],
  month_format_narrow => [
    "o",
    "b",
    "l",
    "n",
    "t",
    "s",
    "z",
    "m",
    "e",
    "a",
    "d",
    "b",
  ],
  month_format_wide => [
    "ng\N{U+0254}n os\N{U+00fa}",
    "ng\N{U+0254}n b\N{U+025b}\N{U+030c}",
    "ng\N{U+0254}n l\N{U+00e1}la",
    "ng\N{U+0254}n nyina",
    "ng\N{U+0254}n t\N{U+00e1}na",
    "ng\N{U+0254}n sam\N{U+0259}na",
    "ng\N{U+0254}n zamgb\N{U+00e1}la",
    "ng\N{U+0254}n mwom",
    "ng\N{U+0254}n ebul\N{U+00fa}",
    "ng\N{U+0254}n aw\N{U+00f3}m",
    "ng\N{U+0254}n aw\N{U+00f3}m ai dzi\N{U+00e1}",
    "ng\N{U+0254}n aw\N{U+00f3}m ai b\N{U+025b}\N{U+030c}",
  ],
  month_stand_alone_abbreviated => [
    "ngo",
    "ngb",
    "ngl",
    "ngn",
    "ngt",
    "ngs",
    "ngz",
    "ngm",
    "nge",
    "nga",
    "ngad",
    "ngab",
  ],
  month_stand_alone_narrow => [
    "o",
    "b",
    "l",
    "n",
    "t",
    "s",
    "z",
    "m",
    "e",
    "a",
    "d",
    "b",
  ],
  month_stand_alone_wide => [
    "ng\N{U+0254}n os\N{U+00fa}",
    "ng\N{U+0254}n b\N{U+025b}\N{U+030c}",
    "ng\N{U+0254}n l\N{U+00e1}la",
    "ng\N{U+0254}n nyina",
    "ng\N{U+0254}n t\N{U+00e1}na",
    "ng\N{U+0254}n sam\N{U+0259}na",
    "ng\N{U+0254}n zamgb\N{U+00e1}la",
    "ng\N{U+0254}n mwom",
    "ng\N{U+0254}n ebul\N{U+00fa}",
    "ng\N{U+0254}n aw\N{U+00f3}m",
    "ng\N{U+0254}n aw\N{U+00f3}m ai dzi\N{U+00e1}",
    "ng\N{U+0254}n aw\N{U+00f3}m ai b\N{U+025b}\N{U+030c}",
  ],
  name => "Ewondo",
  native_language => "ewondo",
  native_name => "ewondo",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "nno",
    "nnb",
    "nnl",
    "nnny",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n as\N{U+00fa}",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n b\N{U+025b}\N{U+030c}",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n l\N{U+00e1}la",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n nyina",
  ],
  quarter_stand_alone_abbreviated => [
    "nno",
    "nnb",
    "nnl",
    "nnny",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n as\N{U+00fa}",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n b\N{U+025b}\N{U+030c}",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n l\N{U+00e1}la",
    "ns\N{U+00e1}mb\N{U+00e1} ng\N{U+0254}n nyina",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
